@@ -1,5 +1,7 @@
+CREATE SEQUENCE sp_user_seq;
+
 CREATE TABLE spops_user (
- user_id       serial,
+ user_id       int not null,
  login_name    varchar(25) not null,
  password      varchar(30) not null,
  first_name    varchar(50) null,
@@ -11,8 +13,10 @@ CREATE TABLE spops_user (
 );
 
 
+CREATE SEQUENCE sp_group_seq;
+
 CREATE TABLE spops_group (
- group_id      serial,
+ group_id      int not null,
  name          varchar(30) not null,
  notes         text null,
  primary key   ( group_id )
@@ -26,8 +30,10 @@ CREATE TABLE spops_group_user (
 );
 
 
+CREATE SEQUENCE sp_security_seq;
+
 CREATE TABLE spops_security (
- sid            serial,
+ sid            int not null,
  class          varchar(60) not null,
  object_id      varchar(150) default '0',
  scope          char(1) not null,
@@ -38,8 +44,10 @@ CREATE TABLE spops_security (
 );
 
 
+CREATE SEQUENCE sp_doodad_seq;
+
 CREATE TABLE spops_doodad (
- doodad_id      serial,
+ doodad_id      int not null,
  name           varchar(100) not null,
  description    text null,
  unit_cost      numeric(10,2) default 0,
